@@ -1,14 +1,12 @@
-from typing import List, Union
+from typing import List
 
 from statham.dsl.constants import Maybe
 from statham.dsl.elements import (
-    AnyOf,
     Array,
     Boolean,
     Integer,
     Null,
     Number,
-    OneOf,
     Object,
     String,
 )
